//
//  NSStringHelpers.h
//  GlyphsCore
//
//  Created by Georg Seifert on 06.08.09.
//  Copyright 2009 schriftgestaltung.de. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#define MAX_UNICODE 0x10FFFF

NSString *GSFloatToStringFull(CGFloat Float, int precision);

NSString *GSFloatToStringWithPrecision(CGFloat Float, int precision);

void GSFloatToStringWithPrecisionToBuffer(char **buffer, CGFloat Float, int precision);

NSString *GSFloatToStringWithPrecisionMin(CGFloat Float, int precision, int minPrecision);

NSString *GSFloatToStringWithPrecisionLocalized(CGFloat Float, int precision);

NSString *GSFloatToStringWithPrecisionLocale(CGFloat Float, int precision, NSLocale *locale);

NSString *GSFloatToStringLocalized(CGFloat Float);

NSString *GSFloatToString(CGFloat Float);

NSString *GSPointToString(NSPoint P);

void GSIndexPathToBuffer(char **buffer, NSIndexPath *indexPath, BOOL addSpace);

NSString *GSStringFromIndexPath(NSIndexPath *indexPath, BOOL addSpace);

NSIndexPath *GSIndexPathFromString(NSString *string);

NSArray* GSIntListFromIndexPath(NSIndexPath *indexPath);
NSIndexPath *GSIndexPathFromIntList(NSArray*intList);

@interface NSString (UUID)

+ (NSString *)UUID;

+ (NSString *)hexStringFromInt:(NSInteger)integer;

+ (NSString *)hexStringFromUnsignedInteger:(NSUInteger)integer;

- (int)hexStringToInt;

+ (NSString *)stringWithChar:(UTF32Char)aChar;

- (NSString *)ascciString;

- (NSUInteger)countOfChar:(char)aChar;

+ (NSString *)pathForTemporaryFileWithPrefix:(NSString *)prefix;

- (NSString *)absolutePathFromBaseDirPath:(NSString *)baseDirPath;

- (NSString *)relativePathFromBaseDirPath:(NSString *)baseDirPath;

//- (NSString *)encodeForPlist;

/**
 @param index A 16-bit character index, by reference. If the index points to a high surrogate character, it will be incremented on output so that the low surrogate is skipped.
 */
- (UTF32Char)character32AtIndex:(NSUInteger *)index;

+ (NSString *)encodeForFilePath:(NSString *)String;

+ (NSString *)encodeForASCII:(NSString *)string;

+ (NSString *)createStringForKey:(CGKeyCode)keyCode;

- (NSString *)stringByDeletingDotSuffix;

- (NSString *)dotSuffix;

- (NSString *)stringByAppendingDotSuffix:(NSString *)suffix;

- (float)localizedFloatValue;

- (double)localizedDoubleValue;

- (NSString *)stringWithFirstLower;

- (NSString *)stringWithFirstUpper;

- (NSString *)camelCaseToSentenceCase;

- (NSRange)rangeOfLine:(NSUInteger)line;

- (BOOL)isNumber;

- (BOOL)isAllDigits;

- (BOOL)isHexCapitalString;

- (BOOL)isHexCapitalStringWithLength:(NSUInteger)length;

@end

unsigned short writeInt(int n, char *restrict s);

BOOL stringNeedsQuotes(NSString *string);

void writeKey(FILE *File, NSString *Key);

BOOL writeKeyValueStringEscape(FILE *File, NSString *Key, NSString *Value, BOOL escape);

BOOL writeKeyValueString(FILE *File, NSString *Key, NSString *Value);
BOOL writeKeyValueStringLine(FILE *File, NSString *Key, NSString *Value);
BOOL writeKeyValueStringSimple(FILE *File, NSString *Key, NSString *Value);
BOOL writeKeyValueInt(FILE *File, NSString *Key, int Value);

BOOL writeKeyValueData(FILE *File, NSString *Key, NSData *Value);

BOOL writeKeyValueInt(FILE *File, NSString *Key, int Value);
BOOL writeFloat(FILE *file, CGFloat value, int precision);
BOOL writeKeyValueFloat(FILE *File, NSString *Key, CGFloat Value);
BOOL writeKeyValueFloatPrecision(FILE *File, NSString *Key, CGFloat Value, int precision);

BOOL writePoint(FILE *File, NSPoint pt, BOOL Compact);
BOOL writeTuple2(FILE *File, char *key, CGFloat value1, CGFloat value2, int precision);
BOOL writeColor(FILE *File, char* key, NSColor *color);
BOOL writeTransform(FILE *File, NSAffineTransformStruct ts, BOOL Compact);
char *writeTransformToBuffer(NSAffineTransformStruct ts, char *buffer);
short actualPrecision(CGFloat Float, int precision);
BOOL writeDateString(FILE *file, NSDate *date);
